@@ -30,7 +30,7 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
     if param_var0 != None:
 
         # solve the ode function using the initial input parameter
-        C = sh.sol_ode(model, var0(param_var0), t, param)
+        C = sol_ode(model, var0(param_var0), t, param)
 
         # times the parameter with 1.0001
         param_var0_new = param_var0
@@ -43,10 +43,10 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
             param_new[index[0]] = 1.0001 * var
 
         # solve the ode function using the changed parameter
-        C_sens = sh.sol_ode(model, var0(param_var0_new), t, param_new)
+        C_sens = sol_ode(model, var0(param_var0_new), t, param_new)
     else:
         # solve the ode function using the initial input parameter
-        C = sh.sol_ode(model, var0, t, param)
+        C = sol_ode(model, var0, t, param)
 
         # times the parameter with 1.0001
         param_new = param
@@ -56,7 +56,7 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
             param_new[index[0]] = 1.0001 * var
 
         # solve the ode function using the changed parameter
-        C_sens = sh.sol_ode(model, var0, t, param_new)
+        C_sens = sol_ode(model, var0, t, param_new)
     # calculate the sensitivity of the parameter along the time or length
     if xlabel == "time":
         try:
