@@ -5,7 +5,7 @@ from .sol_ode import sol_ode
 from .delay import delay
 from .two_position import two_position
 
-def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1, y_index = 0):
+def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1, y_index = -1):
     
     """
     Create a two position controller to adjust the parameter of input ode function,
@@ -18,9 +18,8 @@ def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1,
         xlimit (list): Setpoints for measured element.
         ylimit (list): Setpoints for control element.
         Tt (float): Specified dead time.
-        x_index (int, optional): The column index of control element in the
+        x_index (int, optional): The column index of measured element in the
                                      solved dataframe. Default to -1.
-        y_index (int, optional): Number of control element. Default to 0.
 
     Returns:
         results: The solved differential equation using adjusted control element.
@@ -55,7 +54,7 @@ def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1,
             x_delay = delay(t, x, Tt, value = 0)
 
         else:
-            x_delay = results
+            x_delay = x
 
         # control the y value by teo position controller.
         y = two_position(x_delay[i], y, xlimit, ylimit)
